unit KADaoReg;
{$I CommonDirectives.pas}
interface
Uses Classes {$IFNDEF D6UP}, DsgnIntf{$ENDIF}
             {$IFDEF D6UP},  DesignIntf, DesignWindows,  DesignEditors{$ENDIF};

{$I CommonDirectives.pas}
Type
//******************************************************************************
//                           EDITOR DEFINITIONS - KADaoDBEngine
//******************************************************************************
  TEngEngineTypeEditor = class(TIntegerProperty)
    Public
     function  GetValue: string; override;
     Procedure GetValues( Proc: TGetStrProc);override;
     procedure SetValue(const Value: string); override;                                               
     Function  GetAttributes: TPropertyAttributes; override;
    End;

  TEngSystemDatabaseNameEditor = class(TStringProperty)
    Public
      Procedure Edit;override;
      Procedure SetValue(const Value: string); override;
      Function  GetAttributes: TPropertyAttributes; override;
    End;

  {$IFDEF DYNADAO}
  TEngDaoVersionEditor = class(TStringProperty)
    Public
      Procedure GetValues( Proc: TGetStrProc); override;
      Procedure SetValue(const Value: string); override;
      Function  GetAttributes: TPropertyAttributes; override;
    End;
  {$ENDIF}
//******************************************************************************
//                           EDITOR DEFINITIONS - KADaoWorkspace
//******************************************************************************
  TWorkEngineTypeEditor = class(TIntegerProperty)
    Public
     function  GetValue: string; override;
     Procedure GetValues( Proc: TGetStrProc);override;
     procedure SetValue(const Value: string); override;
     Function  GetAttributes: TPropertyAttributes; override;
    End;

  TWorkDefaultCursorDriverTypeEditor = class(TIntegerProperty)
    Public
     function  GetValue: string; override;
     Procedure GetValues( Proc: TGetStrProc);override;
     procedure SetValue(const Value: string); override;
     Function  GetAttributes: TPropertyAttributes; override;
    End;
//******************************************************************************
//                           EDITOR DEFINITIONS - KADaoDatabase
//******************************************************************************
TDBDatabaseTypeEditor = class(TStringProperty)
    Public
      Procedure GetValues( Proc: TGetStrProc); override;
      Procedure SetValue(const Value: string); override;
      Function  GetAttributes: TPropertyAttributes; override;
    End;

TDBDatabaseNameEditor = class(TStringProperty)
    Public
      Procedure Edit;override;
      Procedure SetValue(const Value: string); override;
      Function  GetAttributes: TPropertyAttributes; override;
    End;

TDBSystemDatabaseNameEditor = class(TStringProperty)
    Public
      Procedure Edit;override;
      Procedure SetValue(const Value: string); override;
      Function  GetAttributes: TPropertyAttributes; override;
    End;

TDBEngineTypeEditor = class(TIntegerProperty)
    Public
     function  GetValue: string; override;
     Procedure GetValues( Proc: TGetStrProc);override;
     procedure SetValue(const Value: string); override;
     Function  GetAttributes: TPropertyAttributes; override;
    End;

TDBDefaultCursorDriverTypeEditor = class(TIntegerProperty)
    Public
     function  GetValue: string; override;
     Procedure GetValues( Proc: TGetStrProc);override;
     procedure SetValue(const Value: string); override;
     Function  GetAttributes: TPropertyAttributes; override;
    End;


TDBWorkspaceEditor = class(TStringProperty)
    Public
      Procedure GetValues( Proc: TGetStrProc); override;
      Function  GetAttributes: TPropertyAttributes; override;
    End;

{$IFDEF DYNADAO}
TDBDaoVersionEditor = class(TStringProperty)
    Public
      Procedure GetValues( Proc: TGetStrProc); override;
      Procedure SetValue(const Value: string); override;
      Function  GetAttributes: TPropertyAttributes; override;
    End;
{$ENDIF}
//******************************************************************************
//                           EDITOR DEFINITIONS - KADaoInfo
//******************************************************************************
  TDIDatabaseNameEditor = class(TStringProperty)
    Public
      Procedure Edit;override;
      Procedure SetValue(const Value: string); override;
      Function  GetAttributes: TPropertyAttributes; override;
    End;

  TDIDLLNameEditor = class(TStringProperty)
    Public
      Procedure Edit;override;
      Procedure SetValue(const Value: string); override;
      Function  GetAttributes: TPropertyAttributes; override;
    End;
//******************************************************************************

procedure Register;

Implementation
Uses SysUtils, Forms, Dialogs, KDaoDBEngine, KDaoWorkspace, KDaoDatabase,
     KADaoInfo, DaoApi, KADaoEncrypter, TypInfo;

//******************************************************************************
//                           EDITOR CODE - KADaoDBEngine
//******************************************************************************
//******************************************************** KADaoDBEngine Editors
//*********************************************************** Engine Type Editor
Function TEngEngineTypeEditor.GetAttributes: TPropertyAttributes;
Begin
  Result := Inherited GetAttributes + [paValueList, paSortList];
End;

Function  TEngEngineTypeEditor.GetValue: string;
Begin
 if GetComponent(0) is TKADaoDBEngine then
    Begin
      if TKADaoDBEngine(GetComponent(0)).EngineType=DaoApi.dbUseODBC then
         Result:='dbUseODBC'
      Else
         Result:='dbUseJet';
    End;
End;

Procedure TEngEngineTypeEditor.GetValues( Proc: TGetStrProc);
Begin
  if GetComponent(0) is TKADaoDBEngine then
     Begin
       Proc('dbUseODBC');
       Proc('dbUseJet');
     End;
End;


procedure TEngEngineTypeEditor.SetValue(const Value: string);
Var
 Dat : Integer;
Begin
  if GetComponent(0) is TKADaoDBEngine then
       Begin
       if Value='dbUseODBC' Then
          Dat:=DaoApi.dbUseODBC
       Else
          Dat:=DaoApi.dbUseJet;
       Inherited SetValue(IntToStr(Dat));
       Modified;
     End;
End;


//******************************************************* System Database Editor
Function TEngSystemDatabaseNameEditor.GetAttributes: TPropertyAttributes;
Begin
  Result:= [paDialog];
End;

Procedure TEngSystemDatabaseNameEditor.SetValue(const Value: string);
Begin
if GetComponent(0) is TKADaoDBEngine then
  Begin
    inherited SetValue(Value);
    Modified;
  End;
End;

procedure TEngSystemDatabaseNameEditor.Edit;
var
   DlgChooseDatabase : TOpenDialog;
   DBase             : TKADaoDBEngine;
   Filter            : String;
Begin
   DBase:=TKADaoDBEngine(GetComponent(0));
   DlgChooseDatabase := TOpenDialog.Create(Nil);
   DlgChooseDatabase.FilterIndex:=1;
   DlgChooseDatabase.DefaultExt:='mdw';
   DlgChooseDatabase.InitialDir:= ExtractFilePath(DBase.SystemDatabase);
   DlgChooseDatabase.FileName  := ExtractFileName(DBase.SystemDatabase);
   if DlgChooseDatabase.FileName <> '' Then Filter := AnsiLowerCase(ExtractFileExt(DlgChooseDatabase.FileName));
   System.Delete(Filter,1,1);
   DlgChooseDatabase.DefaultExt:= Filter;
   if AnsiLowerCase(ExtractFileExt(DlgChooseDatabase.FileName))='.mda' Then DlgChooseDatabase.FilterIndex:=1
   Else
     if AnsiLowerCase(ExtractFileExt(DlgChooseDatabase.FileName))='.mdw' Then DlgChooseDatabase.FilterIndex:=1
   Else
     if AnsiLowerCase(ExtractFileExt(DlgChooseDatabase.FileName))='.mdb' Then DlgChooseDatabase.FilterIndex:=2
   Else
     DlgChooseDatabase.FilterIndex:=3;
   Filter:='Microsoft Access security files (*.mda *.mdw)|*.mda;*.mdw';
   Filter:=Filter+'|Microsoft Access (*.mdb)|*.mdb';
   Filter:=Filter+'|All files (*.*)|*.*';
   DlgChooseDatabase.Title:='Choose System Database:';
   DlgChooseDatabase.Options:=[ofFileMustExist,ofPathMustExist,ofHideReadOnly];
   DlgChooseDatabase.Filter :=Filter;
   if DlgChooseDatabase.Execute then SetStrValue(DlgChooseDatabase.FileName);
   DlgChooseDatabase.Free;
   Modified;
End;

//*********************************************************** DAO Version Editor
{$IFDEF DYNADAO}
Procedure TEngDaoVersionEditor.GetValues( Proc: TGetStrProc);
Var
  DBase : TKADaoDBEngine;
  X     : Integer;
Begin
  if GetComponent(0) is TKADaoDBEngine then
  Begin
    DBase := TKADaoDBEngine(GetComponent(0));
    Try
      For X := 0 to DBase.F_DaoVersionList.Count-1 do Proc(DBase.F_DaoVersionList[X]);
    Finally
    End;
  End;
End;

Procedure TEngDaoVersionEditor.SetValue(const Value: string);
Begin
 if GetComponent(0) is TKADaoDBEngine then
  Begin
    inherited SetValue(Value);
    Modified;
  End;
End;

Function TEngDaoVersionEditor.GetAttributes: TPropertyAttributes;
Begin
  Result:= Inherited GetAttributes + [paValueList, paSortList];
End;
{$ENDIF}

//******************************************************************************
//                           EDITOR CODE - KADaoWorkspace
//******************************************************************************
//******************************************************* KADaoWorkspace Editors
//*********************************************************** Engine Type Editor
Function TWorkEngineTypeEditor.GetAttributes: TPropertyAttributes;
Begin
  Result := Inherited GetAttributes + [paValueList, paSortList];
End;

Function  TWorkEngineTypeEditor.GetValue: string;
Begin
 if GetComponent(0) is TKADaoWorkspace then
    Begin
      if TKADaoWorkspace(GetComponent(0)).EngineType=DaoApi.dbUseODBC then
         Result:='dbUseODBC'
      Else
         Result:='dbUseJet';
    End;
End;

Procedure TWorkEngineTypeEditor.GetValues( Proc: TGetStrProc);
Begin
  if GetComponent(0) is TKADaoWorkspace then
     Begin
       Proc('dbUseODBC');
       Proc('dbUseJet');
     End;
End;


procedure TWorkEngineTypeEditor.SetValue(const Value: string);
Var
 Dat : Integer;
Begin
  if GetComponent(0) is TKADaoWorkspace then
       Begin
       if Value='dbUseODBC' Then
          Dat:=DaoApi.dbUseODBC
       Else
          Dat:=DaoApi.dbUseJet;
       Inherited SetValue(IntToStr(Dat));
       Modified;
     End;
End;

//*************************************************** DefaultCursorDriver Editor
Function TWorkDefaultCursorDriverTypeEditor.GetAttributes: TPropertyAttributes;
Begin
  Result := Inherited GetAttributes + [paValueList, paSortList];
End;

Function  TWorkDefaultCursorDriverTypeEditor.GetValue: string;
Var
 DB : TKADaoWorkspace;
Begin
 if GetComponent(0) is TKADaoWorkspace then
    Begin
     DB := TKADaoWorkspace(GetComponent(0));
     Result:='dbUseDefaultCursor';
     if DB.DefaultCursorDriver=DaoApi.dbUseDefaultCursor     then Result:='dbUseDefaultCursor'
     Else
     if DB.DefaultCursorDriver=DaoApi.dbUseODBCCursor        then Result:='dbUseODBCCursor'
     Else
     if DB.DefaultCursorDriver=DaoApi.dbUseServerCursor      then Result:='dbUseServerCursor'
     Else
     if DB.DefaultCursorDriver=DaoApi.dbUseClientBatchCursor then Result:='dbUseClientBatchCursor'
     Else
     if DB.DefaultCursorDriver=DaoApi.dbUseNoCursor          then Result:='dbUseNoCursor';
    End;
End;

Procedure TWorkDefaultCursorDriverTypeEditor.GetValues( Proc: TGetStrProc);
Begin
  if GetComponent(0) is TKADaoWorkspace then
     Begin
       Proc('dbUseDefaultCursor');
       Proc('dbUseODBCCursor');
       Proc('dbUseServerCursor');
       Proc('dbUseClientBatchCursor');
       Proc('dbUseNoCursor');
     End;
End;


procedure TWorkDefaultCursorDriverTypeEditor.SetValue(const Value: string);
Var
 Dat : Integer;
Begin
  if GetComponent(0) is TKADaoWorkspace then
       Begin
       Dat:=DaoApi.dbUseDefaultCursor;
       if Value='dbUseDefaultCursor' Then Dat:=DaoApi.dbUseDefaultCursor
       Else
       if Value='dbUseODBCCursor' Then Dat:=DaoApi.dbUseODBCCursor
       Else
       if Value='dbUseServerCursor' Then Dat:=DaoApi.dbUseServerCursor
       Else
       if Value='dbUseClientBatchCursor' Then Dat:=DaoApi.dbUseClientBatchCursor
       Else
       if Value='dbUseNoCursor' Then Dat:=DaoApi.dbUseNoCursor;
       Inherited SetValue(IntToStr(Dat));
       Modified;
     End;
End;
//******************************************************************************
//                           EDITOR CODE - KADaoDatabase
//******************************************************************************
//******************************************************** KADaoDatabase Editors
Procedure TDBDatabaseTypeEditor.GetValues( Proc: TGetStrProc);
Var
  DBase : TKADaoDatabase;
  X     : Integer;
Begin
  if GetComponent(0) is TKADaoDatabase then
  Begin
    DBase := TKADaoDatabase(GetComponent(0));
    Try
      For X := 0 to DBase.F_DBTypesList.Count-1 do Proc(DBase.F_DBTypesList[X]);
    Finally
    End;
  End;
End;

Procedure TDBDatabaseTypeEditor.SetValue(const Value: string);
Begin
 if GetComponent(0) is TKADaoDatabase then
  Begin
    inherited SetValue(Value);
    Modified;
  End;
End;

Function TDBDatabaseTypeEditor.GetAttributes: TPropertyAttributes;
Begin
  Result:= Inherited GetAttributes + [paValueList, paSortList];
End;


//************************************************************** Database Editor
Function TDBDatabaseNameEditor.GetAttributes: TPropertyAttributes;
Begin
  Result:= [paDialog];
End;

Procedure TDBDatabaseNameEditor.SetValue(const Value: string);
Begin
if GetComponent(0) is TKADaoDatabase then
  Begin
    inherited SetValue(Value);
    Modified;
  End;
End;

procedure TDBDatabaseNameEditor.Edit;
var
   FileName : String;
   DBase    : TKADaoDatabase;
Begin
   DBase:=TKADaoDatabase(GetComponent(0));
   Filename := DBase.F_ChooseDatabase;
   if Filename <> '' then begin
      SetStrValue(Filename);
      Modified;
   end;
End;


//******************************************************* System Database Editor
Function TDBSystemDatabaseNameEditor.GetAttributes: TPropertyAttributes;
Begin
  Result:= [paDialog];
End;

Procedure TDBSystemDatabaseNameEditor.SetValue(const Value: string);
Begin
if GetComponent(0) is TKADaoDatabase then
  Begin
    inherited SetValue(Value);
    Modified;
  End;
End;

procedure TDBSystemDatabaseNameEditor.Edit;
var
   DBase               : TKADaoDatabase;
   Filter              : String;
   DlgChooseDatabase   : TOpenDialog;
Begin
   DBase:=TKADaoDatabase(GetComponent(0));
   DlgChooseDatabase := TOpenDialog.Create(Nil);
   DlgChooseDatabase.FilterIndex:=1;
   DlgChooseDatabase.DefaultExt:='mdw';
   DlgChooseDatabase.InitialDir:= ExtractFilePath(DBase.SystemDatabase);
   DlgChooseDatabase.FileName  := ExtractFileName(DBase.SystemDatabase);
   if DlgChooseDatabase.FileName <> '' Then Filter := AnsiLowerCase(ExtractFileExt(DlgChooseDatabase.FileName));
   System.Delete(Filter,1,1);
   DlgChooseDatabase.DefaultExt:= Filter;
   if AnsiLowerCase(ExtractFileExt(DlgChooseDatabase.FileName))='.mda' Then DlgChooseDatabase.FilterIndex:=1
   Else
     if AnsiLowerCase(ExtractFileExt(DlgChooseDatabase.FileName))='.mdw' Then DlgChooseDatabase.FilterIndex:=1
   Else
     if AnsiLowerCase(ExtractFileExt(DlgChooseDatabase.FileName))='.mdb' Then DlgChooseDatabase.FilterIndex:=2
   Else
     DlgChooseDatabase.FilterIndex:=3;
   Filter:='Microsoft Access security files (*.mda *.mdw)|*.mda;*.mdw';
   Filter:=Filter+'|Microsoft Access (*.mdb)|*.mdb';
   Filter:=Filter+'|All files (*.*)|*.*';
   DlgChooseDatabase.Title:='Choose System Database:';
   DlgChooseDatabase.Options:=[ofFileMustExist,ofPathMustExist,ofHideReadOnly];
   DlgChooseDatabase.Filter :=Filter;
   if DlgChooseDatabase.Execute then SetStrValue(DlgChooseDatabase.FileName);
   DlgChooseDatabase.Free;
   Modified;
End;


//*********************************************************** Engine Type Editor
Function TDBEngineTypeEditor.GetAttributes: TPropertyAttributes;
Begin
  Result := Inherited GetAttributes + [paValueList, paSortList];
End;

Function  TDBEngineTypeEditor.GetValue: string;
Begin
 if GetComponent(0) is TKADaoDatabase then
    Begin
      if TKADaoDatabase(GetComponent(0)).EngineType=DaoApi.dbUseODBC then
         Result:='dbUseODBC'
      Else
         Result:='dbUseJet';
    End;
End;

Procedure TDBEngineTypeEditor.GetValues( Proc: TGetStrProc);
Begin
  if GetComponent(0) is TKADaoDatabase then
     Begin
       Proc('dbUseODBC');
       Proc('dbUseJet');
     End;
End;


procedure TDBEngineTypeEditor.SetValue(const Value: string);
Var
 Dat : Integer;
Begin
  if GetComponent(0) is TKADaoDatabase then
       Begin
       if Value='dbUseODBC' Then
          Dat:=DaoApi.dbUseODBC
       Else
          Dat:=DaoApi.dbUseJet;
       Inherited SetValue(IntToStr(Dat));
       Modified;
     End;
End;
//*************************************************** DefaultCursorDriver Editor
Function TDBDefaultCursorDriverTypeEditor.GetAttributes: TPropertyAttributes;
Begin
  Result := Inherited GetAttributes + [paValueList, paSortList];
End;

Function  TDBDefaultCursorDriverTypeEditor.GetValue: string;
Var
 DB : TKADaoDatabase;
Begin
 if GetComponent(0) is TKADaoDatabase then
    Begin
     DB := TKADaoDatabase(GetComponent(0));
     Result:='dbUseDefaultCursor';
     if DB.DefaultCursorDriver=DaoApi.dbUseDefaultCursor     then Result:='dbUseDefaultCursor'
     Else
     if DB.DefaultCursorDriver=DaoApi.dbUseODBCCursor        then Result:='dbUseODBCCursor'
     Else
     if DB.DefaultCursorDriver=DaoApi.dbUseServerCursor      then Result:='dbUseServerCursor'
     Else
     if DB.DefaultCursorDriver=DaoApi.dbUseClientBatchCursor then Result:='dbUseClientBatchCursor'
     Else
     if DB.DefaultCursorDriver=DaoApi.dbUseNoCursor          then Result:='dbUseNoCursor';
    End;
End;

Procedure TDBDefaultCursorDriverTypeEditor.GetValues( Proc: TGetStrProc);
Begin
  if GetComponent(0) is TKADaoDatabase then
     Begin
       Proc('dbUseDefaultCursor');
       Proc('dbUseODBCCursor');
       Proc('dbUseServerCursor');
       Proc('dbUseClientBatchCursor');
       Proc('dbUseNoCursor');
     End;
End;


procedure TDBDefaultCursorDriverTypeEditor.SetValue(const Value: string);
Var
 Dat : Integer;
Begin
  if GetComponent(0) is TKADaoDatabase then
       Begin
       Dat:=DaoApi.dbUseDefaultCursor;
       if Value='dbUseDefaultCursor'     Then Dat:=DaoApi.dbUseDefaultCursor
       Else
       if Value='dbUseODBCCursor'        Then Dat:=DaoApi.dbUseODBCCursor
       Else
       if Value='dbUseServerCursor'      Then Dat:=DaoApi.dbUseServerCursor
       Else
       if Value='dbUseClientBatchCursor' Then Dat:=DaoApi.dbUseClientBatchCursor
       Else
       if Value='dbUseNoCursor'          Then Dat:=DaoApi.dbUseNoCursor;
       Inherited SetValue(IntToStr(Dat));
       Modified;
     End;
End;


//************************************************************* Workspase Editor
Procedure TDBWorkspaceEditor.GetValues( Proc: TGetStrProc);
Var
  DBase : TKADaoDatabase;
  X     : Integer;
Begin
  if GetComponent(0) is TKADaoDatabase then
  Begin
    DBase := TKADaoDatabase(GetComponent(0));
    Try
      For X := 0 to DBase.CoreDBEngine.Workspaces.Count-1 do
          Begin
            if AnsiCompareText(DBase.CoreDBEngine.Workspaces.Item[X].Name,
                               '#Default Workspace#') <> 0 Then
            Proc(DBase.CoreDBEngine.Workspaces.Item[X].Name);
          End;
    Finally
    End;
  End;
End;

Function TDBWorkspaceEditor.GetAttributes: TPropertyAttributes;
Begin
  Result:= Inherited GetAttributes + [paValueList, paSortList];
End;

//*********************************************************** DAO Version Editor
{$IFDEF DYNADAO}
Procedure TDBDaoVersionEditor.GetValues( Proc: TGetStrProc);
Var
  DBase : TKADaoDatabase;
  X     : Integer;
Begin
  if GetComponent(0) is TKADaoDatabase then
  Begin
    DBase := TKADaoDatabase(GetComponent(0));
    Try
      For X := 0 to DBase.F_DaoVersionList.Count-1 do Proc(DBase.F_DaoVersionList[X]);
    Finally
    End;
  End;
End;

Procedure TDBDaoVersionEditor.SetValue(const Value: string);
Begin
 if GetComponent(0) is TKADaoDatabase then
  Begin
    inherited SetValue(Value);
    Modified;
  End;
End;

Function TDBDaoVersionEditor.GetAttributes: TPropertyAttributes;
Begin
  Result:= Inherited GetAttributes + [paValueList, paSortList];
End;
{$ENDIF}

//******************************************************************************
//                           EDITOR CODE - KADaoInfo
//******************************************************************************
//************************************************************ KADaoInfo Editors
//******************************************************************************
Function TDIDatabaseNameEditor.GetAttributes: TPropertyAttributes;
Begin
  Result:= [paDialog];
End;

Procedure TDIDatabaseNameEditor.SetValue(const Value: string);
Begin
if GetComponent(0) is TKADaoInfo then
  Begin
    inherited SetValue(Value);
    Modified;
  End;
End;

procedure TDIDatabaseNameEditor.Edit;
var
   FileName           : String;
   DBase              : TKADaoInfo;
   DlgChooseDatabase  : TOpenDialog;
   Filter             : String;
Begin
   DBase:=TKADaoInfo(GetComponent(0));
   Filename := DBase.Database;
   DlgChooseDatabase := TOpenDialog.Create(Nil);
   if FileName = '' then
        Begin
           DlgChooseDatabase.FileName   := '';
        End
     Else
        Begin
           DlgChooseDatabase.FileName   := ExtractFileName(FileName);
           DlgChooseDatabase.InitialDir := ExtractFileDir(FileName);
        End;
   DlgChooseDatabase.FilterIndex:=1;     
   Filter:='Microsoft Access (*.mdb)|*.mdb';
   Filter:=Filter+'|All files (*.*)|*.*';
   DlgChooseDatabase.Title:='Choose MS Access Database:';
   DlgChooseDatabase.Options:=[ofPathMustExist,ofFileMustExist,ofHideReadOnly];
   DlgChooseDatabase.Filter :=Filter;
   DlgChooseDatabase.DefaultExt:='mdb';
   if DlgChooseDatabase.Execute then Filename := DlgChooseDatabase.FileName;
   if Filename <> '' then
      begin
      SetStrValue(Filename);
      Modified;
      end;
   DlgChooseDatabase.Free;
End;

//******************************************************************************
Function TDIDLLNameEditor.GetAttributes: TPropertyAttributes;
Begin
  Result:= [paDialog];
End;

Procedure TDIDLLNameEditor.SetValue(const Value: string);
Begin
if GetComponent(0) is TKADaoInfo then
  Begin
    inherited SetValue(Value);
    Modified;
  End;
End;

procedure TDIDLLNameEditor.Edit;
var
   FileName           : String;
   DBase              : TKADaoInfo;
   DlgChooseDatabase  : TOpenDialog;
   Filter             : String;
Begin
   DBase:=TKADaoInfo(GetComponent(0));
   Filename := DBase.DaoInfoDll;
   DlgChooseDatabase := TOpenDialog.Create(Nil);
   if FileName = '' then
        Begin
           DlgChooseDatabase.FileName   := '';
        End
     Else
        Begin
           DlgChooseDatabase.FileName   := ExtractFileName(FileName);
           DlgChooseDatabase.InitialDir := ExtractFileDir(FileName);
        End;
   Filter:='Windows library (*.dll)|*.dll';
   Filter:=Filter+'|All files (*.*)|*.*';
   DlgChooseDatabase.Title:='Choose Micospft DAO Info Library:';
   DlgChooseDatabase.Options:=[ofPathMustExist,ofFileMustExist,ofHideReadOnly];
   DlgChooseDatabase.Filter :=Filter;
   DlgChooseDatabase.DefaultExt:='dll';
   if DlgChooseDatabase.Execute then Filename := DlgChooseDatabase.FileName;
   if Filename <> '' then
      begin
      SetStrValue(Filename);
      Modified;
      end;
   DlgChooseDatabase.Free;
End;

//******************************************************************************
procedure Register;
begin
 //***************** KADaoDBEngine
 RegisterPropertyEditor(TypeInfo(Integer),TKADaoDBEngine,'EngineType', TEngEngineTypeEditor);
 RegisterPropertyEditor(TypeInfo(String) ,TKADaoDBEngine,'SystemDatabase',TEngSystemDatabaseNameEditor);
 {$IFDEF DYNADAO}
 RegisterPropertyEditor(TypeInfo(String),TKADaoDBEngine, 'Version', TEngDaoVersionEditor);
 {$ENDIF}
 //***************** KADaoWorkspace
 RegisterPropertyEditor(TypeInfo(Integer),TKADaoWorkspace,'EngineType', TWorkEngineTypeEditor);
 RegisterPropertyEditor(TypeInfo(Integer),TKADaoWorkspace, 'DefaultCursorDriver', TWorkDefaultCursorDriverTypeEditor);
 //***************** KAAdoDatabase
 RegisterPropertyEditor(TypeInfo(String),TKADaoDatabase,'DatabaseType',TDBDatabaseTypeEditor);
 RegisterPropertyEditor(TypeInfo(String),TKADaoDatabase,'Database',TDBDatabaseNameEditor);
 RegisterPropertyEditor(TypeInfo(String),TKADaoDatabase,'SystemDatabase',TDBSystemDatabaseNameEditor);
 RegisterPropertyEditor(TypeInfo(Integer),TKADaoDatabase, 'EngineType', TDBEngineTypeEditor);
 RegisterPropertyEditor(TypeInfo(Integer),TKADaoDatabase, 'DefaultCursorDriver', TDBDefaultCursorDriverTypeEditor);
 RegisterPropertyEditor(TypeInfo(String),TKADaoDatabase, 'Workspace', TDBWorkspaceEditor);
 {$IFDEF DYNADAO}
 RegisterPropertyEditor(TypeInfo(String),TKADaoDatabase, 'Version', TDBDaoVersionEditor);
 {$ENDIF}
 //***************** KAAdoInfo
 RegisterPropertyEditor(TypeInfo(String),TKADaoInfo,'Database',TDIDatabaseNameEditor);
 RegisterPropertyEditor(TypeInfo(String),TKADaoInfo,'DaoInfoDll',TDIDLLNameEditor);
end;

end.
